@@ -25,5 +25,6 @@ class HwDetect(FilteredCommand):
         return (['/bin/hw-detect'], ['ERROR', 'PROGRESS'])
 
     def error(self, priority, question):
-        self.frontend.error_dialog(self.description(question))
+        self.frontend.error_dialog(self.description(question),
+                                   self.extended_description(question))
         return super(HwDetect, self).error(priority, question)
