@@ -25,5 +25,6 @@ class YabootInstaller(FilteredCommand):
                  '/target'], ['ERROR'])
 
     def error(self, priority, question):
-        self.frontend.error_dialog(self.description(question))
+        self.frontend.error_dialog(self.description(question),
+                                   self.extended_description(question))
         return super(YabootInstaller, self).error(priority, question)
