@@ -1,11 +1,30 @@
 #! /usr/bin/python
 # -*- coding: UTF-8 -*-
 
+# Copyright (C) 2005, 2006 Canonical Ltd.
+# Written by Colin Watson <cjwatson@ubuntu.com>.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
 import sys
 import os
+import types
 import signal
 import subprocess
 import re
+import syslog
 import debconf
 try:
     from debconf import DebconfCommunicator
@@ -25,8 +44,7 @@ DEBCONF_IO_HUP = 8
 class FilteredCommand(object):
     def __init__(self, frontend, db=None):
         self.frontend = frontend
-        # db does not normally need to be specified; it is only useful to
-        # set it if frontend=None.
+        # db does not normally need to be specified.
         self.db = db
         self.done = False
         self.current_question = None
@@ -37,14 +55,17 @@ class FilteredCommand(object):
         if ('UBIQUITY_DEBUG_CORE' in os.environ and
             os.environ['UBIQUITY_DEBUG_CORE'] == '1'):
             message = fmt % args
-            print >>sys.stderr, '%s: %s' % (PACKAGE, message)
-            sys.stderr.flush()
+            syslog.syslog(syslog.LOG_DEBUG, '%s: %s' % (PACKAGE, message))
 
     def start(self, auto_process=False):
         self.status = None
         self.db = DebconfCommunicator(PACKAGE, cloexec=True)
         prep = self.prepare()
-        self.command = prep[0]
+        self.command = ['log-output', '-t', 'ubiquity', '--pass-stdout']
+        if isinstance(prep[0], types.StringTypes):
+            self.command.append(prep[0])
+        else:
+            self.command.extend(prep[0])
         question_patterns = prep[1]
         if len(prep) > 2:
             env = prep[2]
@@ -102,7 +123,11 @@ class FilteredCommand(object):
         # from within the debconffiltered Config class.
         if self.frontend is None:
             prep = self.prepare()
-            self.command = prep[0]
+            self.command = ['log-output', '-t', 'ubiquity', '--pass-stdout']
+            if isinstance(prep[0], types.StringTypes):
+                self.command.append(prep[0])
+            else:
+                self.command.extend(prep[0])
             self.debug("Starting up '%s' for %s.%s", self.command,
                        self.__class__.__module__, self.__class__.__name__)
             if len(prep) > 2:
@@ -202,20 +227,19 @@ class FilteredCommand(object):
         choices = self.choices(question)
         choices_c = self.choices_untranslated(question)
         for i in range(len(choices)):
-#            print >>sys.stderr, i
-#            print >>sys.stderr, choices[i]
-#            print >>sys.stderr, choices_c[i]
-            
             _map[choices[i]] = choices_c[i]
-        return _map        
+        return _map
 
     def description(self, question):
         return unicode(self.db.metaget(question, 'description'),
                        'utf-8', 'replace')
 
     def extended_description(self, question):
-        return unicode(self.db.metaget(question, 'extended_description'),
+        self.db.capb('escape')
+        data = unicode(self.db.metaget(question, 'extended_description'),
                        'utf-8', 'replace')
+        self.db.capb('')
+        return data
 
     def translate_to_c(self, question, value):
         choices = self.choices(question)
